#!/usr/bin/env python3

import logging
import os
import subprocess


class Launcher(object):
    """ Класс для запуска приложений пользователем autologon """
    def __init__(self, app):
        self.args = ['sudo', '-u', 'autologon']
        self.app = app

    def run(self, args, autologon=True, pipe=True):
        """ Запуск приложения с параметрами
        Args:
            args(list of str) - список параметров
            autologon(bool) - флаг использования пользователя autologon при вызове приложения
            pipe(bool) - флаг необходимости подключаться к потокам ввода/вывода
        Returns:
            subprocess.Popen - хэндлер запущенного процесса
        """
        args = (self.args if autologon else []) + [self.app] + args
        logging.info("Запуск %s: '%s'" % (self.app, " ".join(args)))
        os.environ["DISPLAY"] = ":255"
        os.environ["XAUTHORITY"] = "/home/autologon/.Xauthority"
        if pipe:
            p = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
        else:
            p = subprocess.Popen(args)
        logging.debug("PID процесса - %s" % str(p.pid))
        return p
