#!/usr/bin/env python3

class Option(object):
    """ Отдельная настройка
    Args:
        name(str) - имя настройки в секции section
        text(str) - название настройки
        specification(str) - описание настройки
        paramsFunc(lambda) - метод получения списка параметров для отображения в диалоге
        checkValueFunc(lambda) - метод проверки введённого пользователем значения
    """
    def __init__(self, name, type, section, text='', specification='', defaultValue='', params='', hidden=False):
        self.name = name
        self.type = type
        self.section = section
        self.text = text
        self.specification = specification
        self.defaultValue = defaultValue
        self.params = params
        self.value = defaultValue
        self.hidden = hidden
        self.paramsFunc = lambda params, value: self.params
        self.checkValueFunc = lambda value: True

    def __contains__(self, item):
        if self.type == 'checkboxtree':
            return item in list(filter(lambda x: x, self.value.split(';')))
        return False

    def getValueDescription(self):
        if self.type == 'dict':
            return self.params[self.value]
        return self.value

    def getParams(self):
        return self.paramsFunc(self.params, self.value)